@@ -15,6 +15,7 @@ class TestingManager(BaseTestingManager):
     Test manager class which prepares infrastructure for tests.
     After tests are finished, destroys the infrastructure.
     """
+
     def __init__(self, credentials: Credentials, config: CfToolConfig):
         super().__init__(credentials)
 
@@ -28,9 +29,7 @@ class TestingManager(BaseTestingManager):
 
         :return: No return.
         """
-        if not self.is_global_prefix_set():
-            self.set_global_prefix()
-
+        self.set_global_prefix(override=False)
         self.__destroy_infrastructure()
         self.__create_infrastructure()
 
@@ -41,7 +40,6 @@ class TestingManager(BaseTestingManager):
         :return: No return.
         """
         self.__destroy_infrastructure()
-
         self.delete_global_prefix()
 
     """
